@@ -4,11 +4,11 @@ from decimal import Decimal
 
 from trytond.i18n import gettext
 from trytond.model import ModelSQL, fields
-from trytond.pool import PoolMeta, Pool
-from trytond.pyson import Eval
-
 from trytond.modules.account.exceptions import AccountMissing
 from trytond.modules.company.model import CompanyValueMixin
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
+from trytond.transaction import Transaction
 
 
 class Configuration(metaclass=PoolMeta):
@@ -24,8 +24,7 @@ class Configuration(metaclass=PoolMeta):
                 ],
             states={
                 'required': Eval('cash_rounding', False),
-                },
-            depends=['cash_rounding']))
+                }))
     cash_rounding_debit_account = fields.MultiValue(fields.Many2One(
             'account.account', "Cash Rounding Debit Account",
             domain=[
@@ -35,8 +34,7 @@ class Configuration(metaclass=PoolMeta):
                 ],
             states={
                 'required': Eval('cash_rounding', False),
-                },
-            depends=['cash_rounding']))
+                }))
 
     @classmethod
     def multivalue_model(cls, field):
@@ -61,16 +59,14 @@ class ConfigurationCashRoundingAccount(ModelSQL, CompanyValueMixin):
             ('type', '!=', None),
             ('closed', '!=', True),
             ('company', '=', Eval('company', -1)),
-            ],
-        depends=['company'])
+            ])
     cash_rounding_debit_account = fields.Many2One(
         'account.account', "Cash Rounding Debit Account",
         domain=[
             ('type', '!=', None),
             ('closed', '!=', True),
             ('company', '=', Eval('company', -1)),
-            ],
-        depends=['company'])
+            ])
 
 
 class Invoice(metaclass=PoolMeta):
@@ -80,8 +76,7 @@ class Invoice(metaclass=PoolMeta):
         "Cash Rounding",
         states={
             'readonly': Eval('state') != 'draft',
-            },
-        depends=['state'])
+            })
 
     @fields.depends('company', 'type')
     def on_change_company(self):
@@ -129,18 +124,26 @@ class Invoice(metaclass=PoolMeta):
                     total_amounts[invoice.id] = amount
         return amounts
 
-    @fields.depends('currency', 'payment_term', 'company', 'invoice_date')
+    @fields.depends(
+        'currency', 'payment_term', 'company', 'invoice_date',
+        'payment_term_date')
     def _cash_round_total_amount(self, amount):
         "Round total amount according to cash rounding"
         from trytond.modules.account_invoice.exceptions import (
             PaymentTermComputeError)
+        pool = Pool()
+        Date = pool.get('ir.date')
         if self.currency:
             amounts = [amount]
             if self.payment_term and self.company:
+                with Transaction().set_context(company=self.company.id):
+                    today = Date.today()
+                payment_date = (
+                    self.payment_term_date or self.invoice_date or today)
                 try:
                     term_lines = self.payment_term.compute(
                         amount, self.company.currency,
-                        self.invoice_date)
+                        payment_date)
                     amounts = [a for _, a in term_lines]
                 except PaymentTermComputeError:
                     pass
