@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
 
@@ -13,8 +13,7 @@ class Purchase(metaclass=PoolMeta):
         "Cash Rounding",
         states={
             'readonly': Eval('state') != 'draft',
-            },
-        depends=['state'])
+            })
 
     @fields.depends('party')
     def on_change_party(self):
@@ -57,12 +56,16 @@ class Purchase(metaclass=PoolMeta):
     def _cash_round_total_amount(self, amount):
         from trytond.modules.account_invoice.exceptions import (
             PaymentTermComputeError)
+        pool = Pool()
+        Date = pool.get('ir.date')
         if self.currency:
             amounts = [amount]
             if self.payment_term and self.company:
+                with Transaction().set_context(company=self.company.id):
+                    today = Date.today()
                 try:
                     term_lines = self.payment_term.compute(
-                        amount, self.company.currency)
+                        amount, self.company.currency, today)
                     amounts = [a for _, a in term_lines]
                 except PaymentTermComputeError:
                     pass
