@@ -1,7 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
+from trytond.transaction import Transaction
 
 
 class Sale(metaclass=PoolMeta):
@@ -39,12 +40,16 @@ class Sale(metaclass=PoolMeta):
     def _cash_round_total_amount(self, amount):
         from trytond.modules.account_invoice.exceptions import (
             PaymentTermComputeError)
+        pool = Pool()
+        Date = pool.get('ir.date')
         if self.currency:
             amounts = [amount]
             if self.payment_term and self.company:
+                with Transaction().set_context(company=self.company.id):
+                    today = Date.today()
                 try:
                     term_lines = self.payment_term.compute(
-                        amount, self.company.currency)
+                        amount, self.company.currency, today)
                     amounts = [a for _, a in term_lines]
                 except PaymentTermComputeError:
                     pass
